@@ -18,10 +18,14 @@
 #include "optiondialog.h"
 
 #include <KConfigGroup>
+#include <KDialogJobUiDelegate>
 #include <KHelpClient>
 #include <KMessageBox>
+#include <KService>
 #include <KShell>
 
+#include <KIO/ApplicationLauncherJob>
+
 #include <QAbstractEventDispatcher>
 #include <QDesktopServices>
 #include <QLayout>
@@ -374,13 +378,21 @@ void KDFWidget::contextMenuRequested(const QPoint &p)
 
     mPopup = new QMenu(nullptr);
     mPopup->setTitle(disk->mountPoint());
-    QAction *mountPointAction = mPopup->addAction(i18n("Mount Device"));
-    QAction *umountPointAction = mPopup->addAction(i18n("Unmount Device"));
+    QAction *mountPointAction = mPopup->addAction(QIcon::fromTheme(QStringLiteral("media-mount")), i18n("Mount Device"));
+    QAction *umountPointAction = mPopup->addAction(QIcon::fromTheme(QStringLiteral("media-eject")), i18n("Unmount Device"));
     mPopup->addSeparator();
-    QAction *openFileManagerAction = mPopup->addAction(i18n("Open in File Manager"));
+    QAction *openFileManagerAction = mPopup->addAction(QIcon::fromTheme(QStringLiteral("system-file-manager")), i18n("Open in File Manager"));
     mountPointAction->setEnabled(!disk->mounted());
     umountPointAction->setEnabled(disk->mounted());
     openFileManagerAction->setEnabled(disk->mounted());
+
+    QAction *filelightAction = nullptr;
+    KService::Ptr filelight = KService::serviceByDesktopName(QStringLiteral("org.kde.filelight"));
+    if (filelight) {
+        filelightAction = mPopup->addAction(QIcon::fromTheme(filelight->icon()), i18nc("@action:inmenu", "Explore in %1", filelight->name()));
+        filelightAction->setEnabled(disk->mounted());
+    }
+
     QAction *position = mPopup->exec(m_listWidget->mapToGlobal(p));
 
     bool openFileManager = false;
@@ -411,6 +423,11 @@ void KDFWidget::contextMenuRequested(const QPoint &p)
         mDiskList.deleteAllMountedAt(disk->mountPoint());
     } else if (position == openFileManagerAction) {
         openFileManager = true;
+    } else if (position == filelightAction) {
+        auto *job = new KIO::ApplicationLauncherJob(filelight);
+        job->setUrls({QUrl::fromLocalFile(disk->mountPoint())});
+        job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+        job->start();
     }
 
     if (openFileManager) {
